@@ -12,10 +12,10 @@ class AppService(app_external_pb2_grpc.ExternalAppServicer):
     def AppInfo(self, request, context):
         info = generate_package_info()
 
-        result = app_external_pb2.AppInfoResponse()
+        result = app_external_pb2.AppInfoExternalResponse()
         result.processors.extend(
             [
-                app_external_pb2.ProcessorInfo(
+                app_external_pb2.ProcessorExternalInfo(
                     name=processor["name"],
                     attributeSchema=json.dumps(processor["attributes_schema"]),
                 )
