@@ -24,12 +24,12 @@ class ProcessorService(processor_external_pb2_grpc.ExternalProcessorServicer):
         except:
             pass
         for item in self.flow_manager.run(flow_name, content, attributes):
-            yield processor_external_pb2.FlowResponse(
+            yield processor_external_pb2.FlowExecuteResponse(
                 attributes=json.dumps(item.attributes, default=grebble_converter),
                 content=json.dumps(item.content, default=grebble_converter),
                 streamEnd=False,
             )
 
-        yield processor_external_pb2.FlowResponse(
+        yield processor_external_pb2.FlowExecuteResponse(
             data=None, attributes=None, streamEnd=True
         )
